command.c: Document return value of handle_connect().
[paraslash.git] / string.h
index d4627f33f0d3ce07885deff483c847e57df5b32a..10251ae7c10b734bd906a644e0832e29b9e6bd9c 100644 (file)
--- a/string.h
+++ b/string.h
@@ -1,10 +1,6 @@
-/*
- * Copyright (C) 2006-2013 Andre Noll <maan@systemlinux.org>
- *
- * Licensed under the GPL v2. For licencing details see COPYING.
- */
+/* Copyright (C) 2006 Andre Noll <maan@tuebingen.mpg.de>, see file COPYING. */
 
-/** \file string.h exported sybmols from string.c */
+/** \file string.h exported symbols from string.c */
 
 /** Flags that change how content is printed into the buffer. */
 enum para_buffer_flags {
@@ -20,7 +16,7 @@ struct para_buffer {
        size_t size;
        /** The maximal size this buffer may grow. Zero means unlimited. */
        size_t max_size;
-       /** \sa para_buffer_flags. */
+       /** \sa \ref para_buffer_flags. */
        unsigned flags;
        /** The next para_printf() will write at this offset. */
        size_t offset;
@@ -35,24 +31,39 @@ struct para_buffer {
 };
 
 /**
-  * Write the contents of a status item to a para_buffer.
-  *
-  * \param b The para_buffer.
-  * \param n The number of the status item.
-  * \param f A format string.
-  *
-  * \return The return value of the underlying call to para_printf().
-  */
+ * Controls the behavior of for_each_line().
+ *
+ * \sa \ref for_each_line().
+ */
+enum for_each_line_flags {
+       /** Activate read-only mode. */
+       FELF_READ_ONLY = 1 << 0,
+       /** Don't call line handler for the first input line. */
+       FELF_DISCARD_FIRST = 1 << 1,
+};
+
+/** Used for \ref for_each_line(). */
+typedef int line_handler_t(char *, void *);
+int for_each_line(unsigned flags, char *buf, size_t size,
+               line_handler_t *line_handler, void *private_data);
+
+/**
+ * Write the contents of a status item to a para_buffer.
+ *
+ * \param b The para_buffer.
+ * \param n The number of the status item.
+ * \param f A format string.
+ *
+ * \return The return value of the underlying call to \ref para_printf().
+ */
 #define WRITE_STATUS_ITEM(b, n, f, ...) (\
 { \
-       int _ret; \
        if ((b)->flags & PBF_SIZE_PREFIX) { \
-               _ret = para_printf((b), "%02x:" f, n, ## __VA_ARGS__); \
+               para_printf((b), "%02x:" f, (unsigned)n, ## __VA_ARGS__); \
        } else { \
-               _ret = para_printf((b), "%s: " f, status_item_list[(n)], \
+               para_printf((b), "%s: " f, status_item_list[(n)], \
                        ## __VA_ARGS__); \
        } \
-       _ret; \
 } \
 )
 
@@ -67,17 +78,10 @@ __must_check __malloc __printf_1_2 char *make_message(const char *fmt, ...);
 __must_check __malloc char *para_strcat(char *a, const char *b);
 __must_check __malloc char *para_dirname(const char *name);
 __must_check char *para_basename(const char *name);
-void chop(char *buf);
 __must_check __malloc char *para_logname(void);
 __must_check __malloc char *para_homedir(void);
 __malloc char *para_hostname(void);
 __printf_2_3 int para_printf(struct para_buffer *b, const char *fmt, ...);
-/** Used for for_each_line() and for_each_line_ro(). */
-typedef int line_handler_t(char *, void *);
-int for_each_line(char *buf, size_t size, line_handler_t *line_handler,
-       void *private_data);
-int for_each_line_ro(char *buf, size_t size, line_handler_t *line_handler,
-       void *private_data);
 int para_atoi64(const char *str, int64_t *result);
 int para_atoi32(const char *str, int32_t *value);
 int get_loglevel_by_name(const char *txt);
@@ -91,3 +95,7 @@ void freep(void *arg);
 int compute_word_num(const char *buf, const char *delim, int offset);
 char *safe_strdup(const char *src, size_t len);
 char *key_value_copy(const char *src, size_t len, const char *key);
+int skip_cells(const char *s, size_t cells_to_skip, size_t *result);
+__must_check int strwidth(const char *s, size_t *result);
+__must_check int sanitize_str(const char *src, size_t max_width,
+               char **result, size_t *width);